import { computed, isRef } from "vue";
import { useAsyncData, useNuxtApp } from "#imports";
import { hash } from "ohash";
export function useHttp(request, opts = {}) {
  if (!request) {
    throw new Error("[nuxt] [useHttp] request is missing.");
  }
  const key = opts.key || "$h" + hash([request, { ...opts, transform: null }]);
  const _request = computed(() => {
    let r = request;
    if (typeof r === "function") {
      r = r();
    }
    return isRef(r) ? r.value : r;
  });
  const {
    server,
    lazy,
    default: defaultFn,
    transform,
    pick,
    watch,
    initialCache,
    immediate,
    ...fetchOptions
  } = opts;
  const _fetchOptions = reactive({
    ...fetchOptions,
    cache: typeof opts.cache === "boolean" ? void 0 : opts.cache
  });
  const _asyncDataOptions = {
    server,
    lazy,
    default: defaultFn,
    transform,
    pick,
    initialCache,
    immediate,
    watch: [
      _fetchOptions,
      _request,
      ...watch || []
    ]
  };
  const { $http } = useNuxtApp();
  const asyncData = useAsyncData(key, () => {
    const method = opts && opts.method && ["get", "head", "delete", "post", "put", "patch"].includes(opts.method.toLowerCase()) ? opts.method.toLowerCase() : "get";
    return $http["$" + method](_request.value, _fetchOptions);
  }, _asyncDataOptions);
  return asyncData;
}
export function useLazyHttp(request, opts = {}) {
  return useHttp(request, {
    ...opts,
    lazy: true
  });
}
